==> qtjambi-xml-5.15.4-sources.jar: io/qt/xml/QXmlInputSource.java <==
package io.qt.xml;


/**
 * <p>The input data for the QXmlReader subclasses</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlinputsource.html">QXmlInputSource</a></p>
 */
@Deprecated
public class QXmlInputSource extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#QXmlInputSource">QXmlInputSource::QXmlInputSource()</a></p>
     */
    public QXmlInputSource(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlInputSource instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#QXmlInputSource-1">QXmlInputSource::QXmlInputSource(QIODevice*)</a></p>
     */
    public QXmlInputSource(io.qt.core.QIODevice dev){
        super((QPrivateConstructor)null);
        initialize_native(this, dev);
    }
    
    private native static void initialize_native(QXmlInputSource instance, io.qt.core.QIODevice dev);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#data">QXmlInputSource::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#fetchData">QXmlInputSource::fetchData()</a></p>
     */
    @io.qt.QtUninvokable
    public void fetchData(){
        fetchData_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void fetchData_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #fromRawData(io.qt.core.QByteArray, boolean)}
     *  with <code>beginning = false</code>.</p>
     */
    @io.qt.QtUninvokable
    protected final java.lang.String fromRawData(io.qt.core.QByteArray data) {
        return fromRawData(data, (boolean)false);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#fromRawData">QXmlInputSource::fromRawData(QByteArray,bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected java.lang.String fromRawData(io.qt.core.QByteArray data, boolean beginning){
        return fromRawData_native_cref_QByteArray_bool(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data), beginning);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String fromRawData_native_cref_QByteArray_bool(long __this__nativeId, long data, boolean beginning);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#next">QXmlInputSource::next()</a></p>
     */
    @io.qt.QtUninvokable
    public char next(){
        return next_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native char next_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#reset">QXmlInputSource::reset()</a></p>
     */
    @io.qt.QtUninvokable
    public void reset(){
        reset_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void reset_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#setData-1">QXmlInputSource::setData(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public void setData(io.qt.core.QByteArray dat){
        setData_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(dat));
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QByteArray(long __this__nativeId, long dat);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#setData">QXmlInputSource::setData(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void setData(java.lang.String dat){
        setData_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), dat);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QString(long __this__nativeId, java.lang.String dat);
    
    private native static short EndOfData();
    
    public static final short EndOfData = EndOfData();

    private native static short EndOfDocument();
    
    public static final short EndOfDocument = EndOfDocument();

    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlInputSource(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-xml-5.15.13-sources.jar: io/qt/xml/QXmlInputSource.java <==
package io.qt.xml;


/**
 * <p>The input data for the QXmlReader subclasses</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlinputsource.html">QXmlInputSource</a></p>
 */
@Deprecated
public class QXmlInputSource extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#QXmlInputSource">QXmlInputSource::QXmlInputSource()</a></p>
     */
    public QXmlInputSource(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlInputSource instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#QXmlInputSource-1">QXmlInputSource::QXmlInputSource(QIODevice*)</a></p>
     */
    public QXmlInputSource(io.qt.core.QIODevice dev){
        super((QPrivateConstructor)null);
        initialize_native(this, dev);
    }
    
    private native static void initialize_native(QXmlInputSource instance, io.qt.core.QIODevice dev);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#data">QXmlInputSource::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#fetchData">QXmlInputSource::fetchData()</a></p>
     */
    @io.qt.QtUninvokable
    public void fetchData(){
        fetchData_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void fetchData_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #fromRawData(io.qt.core.QByteArray, boolean)}
     *  with <code>beginning = false</code>.</p>
     */
    @io.qt.QtUninvokable
    protected final java.lang.String fromRawData(io.qt.core.QByteArray data) {
        return fromRawData(data, (boolean)false);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#fromRawData">QXmlInputSource::fromRawData(QByteArray,bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected java.lang.String fromRawData(io.qt.core.QByteArray data, boolean beginning){
        return fromRawData_native_cref_QByteArray_bool(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data), beginning);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String fromRawData_native_cref_QByteArray_bool(long __this__nativeId, long data, boolean beginning);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#next">QXmlInputSource::next()</a></p>
     */
    @io.qt.QtUninvokable
    public char next(){
        return next_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native char next_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#reset">QXmlInputSource::reset()</a></p>
     */
    @io.qt.QtUninvokable
    public void reset(){
        reset_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void reset_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#setData-1">QXmlInputSource::setData(QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public void setData(io.qt.core.QByteArray dat){
        setData_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(dat));
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QByteArray(long __this__nativeId, long dat);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlinputsource.html#setData">QXmlInputSource::setData(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void setData(java.lang.String dat){
        setData_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), dat);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QString(long __this__nativeId, java.lang.String dat);
    
    private native static short EndOfData();
    
    public static final short EndOfData = EndOfData();

    private native static short EndOfDocument();
    
    public static final short EndOfDocument = EndOfDocument();

    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlInputSource(QPrivateConstructor p) { super(p); } 
    
}
